@@ -92,11 +92,11 @@ get_contrast_data <- function(model,
                 class(x[[col]]) <- class(x[[col]])[2]
             }
 
-            # mlogit uses a `newdata` with one row per unit-choice and returns
-            # an `idx` column with the choice label in second position
-            if (inherits(model, "mlogit") && inherits(x[[col]], "idx")) {
-                x[[col]] <- NULL
-            }
+            # # mlogit uses a `newdata` with one row per unit-choice and returns
+            # # an `idx` column with the choice label in second position
+            # if (inherits(model, "mlogit") && inherits(x[[col]], "idx")) {
+            #     x[[col]] <- NULL
+            # }
         }
         return(x)
     }
