@@ -1,4 +1,4 @@
-plot_preprocess <- function(dat, v_x, v_color = NULL, v_facet = NULL, condition = NULL, modeldata = NULL) {
+plot_preprocess <- function(dat, v_x, v_color = NULL, v_facet_1 = NULL, v_facet_2 = NULL, condition = NULL, modeldata = NULL) {
     for (v in names(condition$condition)) {
         fun <- function(x, lab) {
             idx <- match(x, sort(unique(x)))
@@ -6,6 +6,11 @@ plot_preprocess <- function(dat, v_x, v_color = NULL, v_facet = NULL, condition
         }
         if (identical(condition$condition[[v]], "threenum")) {
             dat[[v]] <- fun(dat[[v]], c("-SD", "Mean", "+SD"))
+        } else if (identical(condition$condition[[v]], "fivenum")) {
+            labs <- stats::setNames(
+                sort(unique(dat[[v]])),
+                format(sort(unique(dat[[v]])), digits = 2))
+            dat[[v]] <- fun(dat[[v]], names(labs))
         } else if (identical(condition$condition[[v]], "minmax")) {
             dat[[v]] <- fun(dat[[v]], c("Min", "Max"))
         } else if (identical(condition$condition[[v]], "quartile")) {
@@ -19,8 +24,11 @@ plot_preprocess <- function(dat, v_x, v_color = NULL, v_facet = NULL, condition
     if (isTRUE(v_color %in% colnames(dat))) {
         dat[[v_color]] <- factor(dat[[v_color]])
     }
-    if (isTRUE(v_facet %in% colnames(dat))) {
-        dat[[v_facet]] <- factor(dat[[v_facet]])
+    if (isTRUE(v_facet_1 %in% colnames(dat))) {
+        dat[[v_facet_1]] <- factor(dat[[v_facet_1]])
+    }
+    if (isTRUE(v_facet_2 %in% colnames(dat))) {
+      dat[[v_facet_2]] <- factor(dat[[v_facet_2]])
     }
     return(dat)
 }
@@ -30,7 +38,8 @@ plot_build <- function(
     dat,
     v_x,
     v_color = NULL,
-    v_facet = NULL,
+    v_facet_1 = NULL,
+    v_facet_2 = NULL,
     dv = NULL,
     modeldata = NULL,
     points = 0,
@@ -95,12 +104,12 @@ plot_build <- function(
             p <- p + ggplot2::geom_pointrange(
                 data = dat,
                 mapping = aes_obj,
-                position = ggplot2::position_dodge(.15))
+                position = ggplot2::position_dodge(0.15))
         } else {
             p <- p + ggplot2::geom_point(
                 data = dat,
                 mapping = aes_obj,
-                position = ggplot2::position_dodge(.15))
+                position = ggplot2::position_dodge(0.15))
         }
 
     # continuous x-axis
@@ -118,25 +127,29 @@ plot_build <- function(
         aes_args$ymin <- aes_args$ymax <- NULL
         aes_obj <- do.call(ggplot2::aes, aes_args)
         if ("conf.low" %in% colnames(dat)) {
-            p <- p + ggplot2::geom_ribbon(data = dat, aes_obj_ribbon, alpha = .1)
+            p <- p + ggplot2::geom_ribbon(data = dat, aes_obj_ribbon, alpha = 0.1)
             p <- p + ggplot2::geom_line(data = dat, aes_obj)
         }
         p <- p + ggplot2::geom_line(data = dat, aes_obj)
     }
 
-    # facets: 3rd variable and/or multiple effects
-    if (multi_variables && !is.null(v_facet)) {
-        fo <- stats::as.formula(paste("~ marginaleffects_term_index +", v_facet))
+    # facets: 3rd and 4th variable and/or multiple effects
+    ## If pass two facets then make facet grid
+    if (!is.null(v_facet_1) && !is.null(v_facet_2)) {
+      fo <- stats::as.formula(paste(v_facet_2, "~", ifelse(multi_variables, "marginaleffects_term_index +", ""), v_facet_1))
+      p <- p + ggplot2::facet_grid(fo,
+                                   scales = "free",
+                                   labeller = function(x){
+                                     lapply(ggplot2::label_both(x), gsub, pattern = "marginaleffects_term_index: ", replacement="")
+                                   })
+    ## if pass only 1 facet then facet_wrap
+    } else if (!is.null(v_facet_1) && is.null(v_facet_2)) {
+        fo <- stats::as.formula(paste("~", ifelse(multi_variables, "marginaleffects_term_index +", ""), v_facet_1))
         p <- p + ggplot2::facet_wrap(fo, scales = "free")
-        
     } else if (multi_variables) {
         fo <- stats::as.formula("~ marginaleffects_term_index")
         p <- p + ggplot2::facet_wrap(fo, scales = "free")
-        
-    } else if (!is.null(v_facet)) {
-        fo <- stats::as.formula(paste("~", v_facet))
-        p <- p + ggplot2::facet_wrap(fo, scales = "free")
     }
 
     return(p)
-}
\ No newline at end of file
+}
