@@ -48,7 +48,7 @@ plot_slopes <- function(model,
                         condition = NULL,
                         by = NULL,
                         newdata = NULL,
-                        type = "response",
+                        type = NULL,
                         vcov = NULL,
                         conf_level = 0.95,
                         wts = FALSE,
