@@ -33,11 +33,11 @@
 #' + [subset()] call with a single argument to select a subset of the dataset used to fit the model, ex: `newdata = subset(treatment == 1)`
 #' + [dplyr::filter()] call with a single argument to select a subset of the dataset used to fit the model, ex: `newdata = filter(treatment == 1)`
 #' + string:
-#'   - "mean": Marginal Effects at the Mean. Slopes when each predictor is held at its mean or mode.
-#'   - "median": Marginal Effects at the Median. Slopes when each predictor is held at its median or mode.
-#'   - "marginalmeans": Marginal Effects at Marginal Means. See Details section below.
-#'   - "tukey": Marginal Effects at Tukey's 5 numbers.
-#'   - "grid": Marginal Effects on a grid of representative numbers (Tukey's 5 numbers and unique values of categorical predictors).
+#'   - "mean": Slopes evaluated when each predictor is held at its mean or mode.
+#'   - "median": Slopes evaluated when each predictor is held at its median or mode.
+#'   - "balanced": Slopes evaluated on a balanced grid with every combination of categories and numeric variables held at their means.
+#'   - "tukey": Slopes evaluated at Tukey's 5 numbers.
+#'   - "grid": Slopes evaluated on a grid of representative numbers (Tukey's 5 numbers and unique values of categorical predictors).
 #' @param vcov Type of uncertainty estimates to report (e.g., for robust standard errors). Acceptable values:
 #'  * FALSE: Do not compute standard errors. This can speed up computation considerably.
 #'  * TRUE: Unit-level standard errors using the default `vcov(model)` variance-covariance matrix.
@@ -67,12 +67,12 @@
 #' + numeric: vector of length equal to the number of rows in the original data or in `newdata` (if supplied).
 #' + FALSE: Equal weights.
 #' + TRUE: Extract weights from the fitted object with `insight::find_weights()` and use them when taking weighted averages of estimates. Warning: `newdata=datagrid()` returns a single average weight, which is equivalent to using `wts=FALSE`
-#' @param hypothesis specify a hypothesis test or custom contrast using a numeric value, vector, or matrix, a string, a string formula, or a function.
+#' @param hypothesis specify a hypothesis test or custom contrast using a numeric value, vector, or matrix; a string equation; string; a formula, or a function.
 #' + Numeric:
 #'   - Single value: the null hypothesis used in the computation of Z and p (before applying `transform`).
 #'   - Vector: Weights to compute a linear combination of (custom contrast between) estimates. Length equal to the number of rows generated by the same function call, but without the `hypothesis` argument.
 #'   - Matrix: Each column is a vector of weights, as describe above, used to compute a distinct linear combination of (contrast between) estimates. The column names of the matrix are used as labels in the output.
-#' + String formula to specify linear or non-linear hypothesis tests. If the `term` column uniquely identifies rows, terms can be used in the formula. Otherwise, use `b1`, `b2`, etc. to identify the position of each parameter. The `b*` wildcard can be used to test hypotheses on all estimates. If a named vector is used, the names are used as labels in the output. Examples:
+#' + String equation to specify linear or non-linear hypothesis tests. If the `term` column uniquely identifies rows, terms can be used in the formula. Otherwise, use `b1`, `b2`, etc. to identify the position of each parameter. The `b*` wildcard can be used to test hypotheses on all estimates. If a named vector is used, the names are used as labels in the output. Examples:
 #'   - `hp = drat`
 #'   - `hp + drat = 12`
 #'   - `b1 + b2 + b3 = 0`
@@ -84,6 +84,15 @@
 #'   - "meandev": difference between an estimate and the mean of all estimates.
 #'   - "meanotherdev": difference between an estimate and the mean of all other estimates, excluding the current one.
 #'   - "revpairwise", "revreference", "revsequential": inverse of the corresponding hypotheses, as described above.
+#' + Formula:
+#'   - `comparison ~ pairs | group`
+#'   - Left-hand side determines the type of comparison to conduct: `difference` or `ratio`. If the left-hand side is empty, `difference` is chosen.
+#'   - Right-hand side determines the pairs of estimates to compare: `reference`, `sequential`, or `meandev`
+#'   - Optional: Users can supply grouping variables after a vertical bar to conduct comparisons withing subsets.
+#'   - Examples:
+#'      + `~ reference`
+#'      + `ratio ~ pairwise`
+#'      + `difference ~ pairwise | groupid`
 #' + Function:
 #'   - Accepts an argument `x`: object produced by a `marginaleffects` function or a data frame with column `rowid` and `estimate`
 #'   - Returns a data frame with columns `term` and `estimate` (mandatory) and `rowid` (optional).
@@ -126,6 +135,7 @@
 #' @template parallel
 #' @template references
 #' @template order_of_operations
+#' @template options
 #'
 #' @return A `data.frame` with one row per observation (per term/group) and several columns:
 #' * `rowid`: row number of the `newdata` data frame
@@ -171,8 +181,9 @@
 #' # original values, and the whole dataset is duplicated once for each
 #' # combination of the values in `datagrid()`
 #' mfx <- slopes(mod,
-#'               newdata = datagrid(hp = c(100, 110),
-#'               grid_type = "counterfactual"))
+#'     newdata = datagrid(
+#'         hp = c(100, 110),
+#'         grid_type = "counterfactual"))
 #' head(mfx)
 #'
 #' # Heteroskedasticity robust standard errors
@@ -200,16 +211,17 @@
 #'     hypothesis = c(1, -1))
 #'
 #' # two custom contrasts using a matrix of weights
-#' lc <- matrix(c(
-#'     1, -1,
-#'     2, 3),
+#' lc <- matrix(
+#'     c(
+#'         1, -1,
+#'         2, 3),
 #'     ncol = 2)
 #' colnames(lc) <- c("Contrast A", "Contrast B")
 #' slopes(
 #'     mod,
 #'     newdata = "mean",
 #'     hypothesis = lc)
-#' 
+#'
 #' @export
 slopes <- function(model,
                    newdata = NULL,
@@ -227,7 +239,6 @@ slopes <- function(model,
                    eps = NULL,
                    numderiv = "fdforward",
                    ...) {
-
     dots <- list(...)
 
     # very early, before any use of newdata
@@ -236,20 +247,21 @@ slopes <- function(model,
     newdata <- sanitize_newdata_call(scall, newdata, model, by = by)
 
     # build call: match.call() doesn't work well in *apply()
-    call_attr <- c(list(
-        name = "slopes",
-        model = model,
-        newdata = newdata,
-        variables = variables,
-        type = type,
-        vcov = vcov,
-        by = by,
-        conf_level = conf_level,
-        slope = slope,
-        wts = wts,
-        hypothesis = hypothesis,
-        df = df,
-        eps = eps),
+    call_attr <- c(
+        list(
+            name = "slopes",
+            model = model,
+            newdata = newdata,
+            variables = variables,
+            type = type,
+            vcov = vcov,
+            by = by,
+            conf_level = conf_level,
+            slope = slope,
+            wts = wts,
+            hypothesis = hypothesis,
+            df = df,
+            eps = eps),
         list(...))
     call_attr <- do.call("call", call_attr)
 
@@ -335,7 +347,6 @@ avg_slopes <- function(model,
                        eps = NULL,
                        numderiv = "fdforward",
                        ...) {
-
     # order of the first few paragraphs is important
     # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
     # should probably not be nested too deeply in the call stack since we eval.parent() (not sure about this)
